@@ -29,21 +29,37 @@ def setup_dir(config_filename):
         File containing user defined parameters
     """
 
-    base_dir = os.path.abspath(os.path.join(os.getcwd(), "../"))
-
     # Read in config variables
     params = read_config(config_filename)
 
-    # Load parameters
+    # Load parameters    
+    vae_model_dir = params["vae_model_dir"]
     local_dir = params["local_dir"]
-    dataset_name = params["dataset_name"]
-    train_architecture = params["NN_architecture"]
 
-    # Create VAE directories
+    # Directories to create
     output_dirs = [
-        os.path.join(base_dir, dataset_name, "models"),
-        os.path.join(base_dir, dataset_name, "logs"),
-    ]
+        vae_model_dir,
+        local_dir,
+        ]
+
+    # Simulated data directory is only required for 
+    # shift_template_experiment and embed_shift_template_experiment
+    # simulation types
+    # Here, check if this parameter is specified in the config 
+    # file.
+
+    # Training_stats_dir is only needed if training a new VAE model
+    if "training_stats_dir" in params:
+        training_stats_dir = params["training_stats_dir"]
+
+        output_dirs.append(training_stats_dir)
+
+    # simulated_data_dir is only needed for `shift_template_experiment`
+    # and `embed_shift_template_experiment` simulation types
+    if "simulated_data_dir" in params:
+        simulated_data_dir = params["simulated_data_dir"]
+
+        output_dirs.append(simulated_data_dir)
 
     # Check if the following directories exist
     # and if not to create them
@@ -54,35 +70,7 @@ def setup_dir(config_filename):
             print("creating new directory: {}".format(each_dir))
             os.makedirs(each_dir, exist_ok=True)
 
-        # Check if NN architecture directory exist otherwise create
-        NN_dir = os.path.join(each_dir, train_architecture)
-        if not os.path.exists(NN_dir):
-            print("creating new directory: {}".format(NN_dir))
-            os.makedirs(NN_dir, exist_ok=True)
 
-    # Check if analysis output directory exist otherwise create
-    results_dir = os.path.join(base_dir, dataset_name, "results")
-    if not os.path.exists(results_dir):
-        print("creating new directory: {}".format(results_dir))
-        os.makedirs(results_dir, exist_ok=True)
-
-    # Check if 'saved_variables' directory exist otherwise create
-    var_dir = os.path.join(results_dir, "saved_variables")
-    if not os.path.exists(var_dir):
-        print("creating new directory: {}".format(var_dir))
-        os.makedirs(var_dir, exist_ok=True)
-
-    # Create local directories to store intermediate files
-    output_dirs = [
-        os.path.join(local_dir, "experiment_simulated"),
-        os.path.join(local_dir, "partition_simulated"),
-    ]
-
-    # Check if analysis output directory exist otherwise create
-    for each_dir in output_dirs:
-        if not os.path.exists(each_dir):
-            print("creating new directory: {}".format(each_dir))
-            os.makedirs(each_dir, exist_ok=True)
 
 
 def create_experiment_id_file(
@@ -117,7 +105,7 @@ def create_experiment_id_file(
 
     # Load parameters
     sample_id_colname = params["metadata_sample_colname"]
-    dataset_name = params["dataset_name"]
+    is_recount2 = params["is_recount2"]
 
     # Get sample id that maps between metadata and expression files
     map_experiment_sample = metadata[[sample_id_colname]]
@@ -134,7 +122,7 @@ def create_experiment_id_file(
 
     for experiment_id in experiment_ids:
 
-        if "human" in dataset_name.lower():
+        if is_recount2:
             # Some project id values are descriptions
             # We will skip these
             if len(experiment_id) == 9:
